==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/SubjectAlternativeNames.h <==
// public class gnu.java.security.x509.ext.SubjectAlternativeNames

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 2af83a7d175fc3db gnu_java_security_x509_ext_SubjectAlternativeNames
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_SubjectAlternativeNames_H_
#define _JC_gnu_java_security_x509_ext_SubjectAlternativeNames_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_x509_ext_GeneralNames$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_refs	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_nonrefs	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$refs	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$refs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$nonrefs	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object;

typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$fields_struct	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vmethods	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtable	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24SubjectAlternativeNames;
};
extern _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$fields_struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$getNames$d565a0d1c278ffb5(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method_info$getNames$d565a0d1c278ffb5;
extern _jc_method _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vmethods {
	struct _jc_object	*(*getNames$d565a0d1c278ffb5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vmethods	gnu_java_security_x509_ext_SubjectAlternativeNames;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_refs {
	struct _jc_gnu_java_security_x509_ext_GeneralNames$object	*names;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$refs {
    _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_refs	gnu_java_security_x509_ext_SubjectAlternativeNames;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_nonrefs	gnu_java_security_x509_ext_SubjectAlternativeNames;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object {
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_SubjectAlternativeNames, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_SubjectAlternativeNames_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/SubjectAlternativeNames.h <==
// public class gnu.java.security.x509.ext.SubjectAlternativeNames

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 2af83a7d175fc3db gnu_java_security_x509_ext_SubjectAlternativeNames
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_SubjectAlternativeNames_H_
#define _JC_gnu_java_security_x509_ext_SubjectAlternativeNames_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_gnu_java_security_x509_ext_GeneralNames$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_refs	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_nonrefs	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$refs	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$refs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$nonrefs	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object;

typedef struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$fields_struct	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vmethods	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtable	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24SubjectAlternativeNames;
};
extern _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$fields_struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$getNames$d565a0d1c278ffb5(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method_info$getNames$d565a0d1c278ffb5;
extern _jc_method _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vmethods {
	struct _jc_object	*(*getNames$d565a0d1c278ffb5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vmethods	gnu_java_security_x509_ext_SubjectAlternativeNames;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_refs {
	struct _jc_gnu_java_security_x509_ext_GeneralNames$object	*names;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$refs {
    _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_refs	gnu_java_security_x509_ext_SubjectAlternativeNames;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$sub_nonrefs	gnu_java_security_x509_ext_SubjectAlternativeNames;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$object {
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_SubjectAlternativeNames$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$vtype _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_SubjectAlternativeNames, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_SubjectAlternativeNames$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_SubjectAlternativeNames_H_ */
